// TESTS: Button callbacks in deeply nested forms, an validators on custom controls

import { FormControl, Validators, ValidationErrors } from '@angular/forms';

// For the simple async validator
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/observable/of';
import 'rxjs/add/operator/delay';
import 'rxjs/add/operator/map';

const testAsyncValidator = (fc: FormControl): Observable<ValidationErrors> => {
	return Observable.of(fc).delay(5000).map(fc => {
		console.log('Async validator got', fc.value);
		return fc.value === '4200' ? null : { is4200: false };
	});
};



const model = {
	// field: '',
	// field2: '',
	// dynaformtest: {
	// 	a: '',
	// 	valTest: '',
	// 	b: 'Value 2',
	// 	c: 'Maybe',
	// 	d: {
	// 		e: '',
	// 		f: 555,
	// 		g: {
	// 			h: true,
	// 			i: false
	// 		}
	// 	},
	// 	z: 'THE END'
	// }
};

const meta = {
	buttonGroup: { type: 'buttonGroup', label: 'Button Group',
		meta: [
			{ label: 'Say Hello', fnId: 'SAYHELLO' },
			{ label: 'Say Cheese', fnId: 'SAYCHEESE' }
		]
	},
	dynaformtest: {
		meta: {
			validatorTest: {
				validators: [ Validators.required, Validators.minLength(4) ],
				// perhaps have some standard messages for standard failures in the Object.prototype ??
				valFailureMessages: {
					'required': 'This field is required',
					'minlength': 'Please type something longer'
				}
			},
			validatorsOnCustomControl: {
				type: 'dropdownModifiedInput',
				validators: [ Validators.required, Validators.minLength(4) ],
				asyncValidators: testAsyncValidator
			},
			c: { label: 'Property Three', type: 'radio', options: ['Yes', 'No', 'Maybe'], horizontal: 1 },
			d: {
				meta: {
					isWorking: { type: 'radio', 'label': 'Does it work yet?', validators: Validators.required },
					f: { type: 'datepicker' },
					deeplyNestedButtonGroup: { type: 'buttonGroup', label: 'Deeply Nested Buttons',
						meta: [
							{ label: 'Say Hello', fnId: 'SAYHELLO' },
							{ label: 'Say Cheese', fnId: 'SAYCHEESE' }
						]
					}
				}
			}
		}
	}
};

export { model, meta };
